gedidb.TileDBProvider
=====================

.. currentmodule:: gedidb

.. autoclass:: TileDBProvider

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TileDBProvider.__init__
      ~TileDBProvider.get_available_variables
   
   

   
   
   